@@ -20,26 +20,25 @@ Pod::Query - Query pod documents
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION       = '0.05';
-our $DEBUG_TREE    = 0;
-our $DEBUG_FIND    = 0;
-our $DEBUG_INVERT  = 0;
-our $DEBUG_RENDER  = 0;
-our $MOCK_ROOT     = 0;
-our $MOCK_SECTIONS = 0;
+our $VERSION      = '0.06';
+our $DEBUG_TREE   = 0;
+our $DEBUG_FIND   = 0;
+our $DEBUG_INVERT = 0;
+our $DEBUG_RENDER = 0;
+our $MOCK_ROOT    = 0;
 
 
 has [
    qw/
-      path lol
-      tree
-      title
-      events
-   /
+     path lol
+     tree
+     title
+     events
+     /
 ];
 
 =head1 SYNOPSIS
@@ -119,20 +118,7 @@ sub new ( $class, $pod_class, $path_only = 0 ) {
 
    return $s if $path_only;
 
-   my $lol = do {
-      if ( $MOCK_ROOT ) {
-         _mock_root();
-      }
-      else {
-         my $parser = Pod::LOL->new;
-
-         # Normally =for and =begin would otherwise be skipped.
-         $parser->accept_targets( '*' );
-
-         $parser->parse_file( $s->path )->{root};
-      }
-   };
-
+   my $lol = $MOCK_ROOT ? _mock_root() : Pod::LOL->new_root( $s->path );
    $lol = _flatten_for_tags( $lol );
 
    $s->lol( $lol );
@@ -380,10 +366,10 @@ Extracts the complete method information.
 sub find_method ( $s, $method ) {
    $s->find(
       {
-         tag       => qr/ ^ head \d $ /x,
-         text      => quotemeta( $method ) . $s->_is_function_call,
-         nth_group => 0,
-         keep_all  => 1,
+         tag      => qr/ ^ head \d $ /x,
+         text     => quotemeta( $method ) . $s->_is_function_call,
+         nth      => 0,
+         keep_all => 1,
       },
    );
 }
@@ -463,11 +449,12 @@ context sensitive!
 
    Where each section can contain:
    {
-      tag      => "TAG_NAME",     # Find all matching tags.
-      text     => "TEXT_NAME",    # Find all matching texts.
-      keep     => 1,              # Capture the text.
-      keep_all => 1,              # Capture entire section.
-      nth      => 0,              # Use only the nth match.
+      tag       => "TAG_NAME",    # Find all matching tags.
+      text      => "TEXT_NAME",   # Find all matching texts.
+      keep      => 1,             # Capture the text.
+      keep_all  => 1,             # Capture entire section.
+      nth       => 0,             # Use only the nth match.
+      nth_group => 0,             # Use only the nth matching group.
    }
 
    # Return contents of entire head section:
@@ -485,16 +472,6 @@ context sensitive!
 =cut
 
 sub find ( $s, @find_sections ) {
-   @find_sections = (
-
-      # {
-      #    tag      => "Para",
-      #    text     => "SKIP1",
-      #    keep     => 1,
-      #    keep_all => 1,
-      #    nth      => 1,
-      # },
-   ) if $MOCK_SECTIONS;    # TODO: Remove later.
 
    _check_sections( \@find_sections );
    _set_section_defaults( \@find_sections );
@@ -514,9 +491,6 @@ sub find ( $s, @find_sections ) {
       @tree = _invert( @tree );
    }
 
-   # say "tree= ", dumper \@tree;
-   # exit;
-
    _render( $kept_all, @tree );
 }
 
@@ -538,22 +512,22 @@ sub _check_sections ( $sections ) {
          $pod->find(
             # section1
             {
-               tag       => "TAG",
-               text      => "TEXT",
+               tag       => "TAG",  # Search to look for.
+               text      => "TEXT", # Text of the tag to find.
                keep      => 1,      # Must only be in last section.
-               keep_all  => 1,
-               nth       => 0,      # These options ...
-               nth_group => 0,      #   are exclusive.
+               keep_all  => 1,      # Keep this tag and sub tags.
+               nth       => 0,      # Stop searching after find so many matches.
+               nth_group => 0,      # Nth only in the current group.
             },
             # ...
             # sectionN
          );
    ERROR
 
-   die "$error_message" if
-      not $sections
-      or not @$sections
-      or grep { ref() ne ref {} } @$sections;
+   die "$error_message"
+     if not $sections
+     or not @$sections
+     or grep { ref() ne ref {} } @$sections;
 
    # keep_all should only be in the last section
    my $last = $#$sections;
@@ -608,8 +582,8 @@ sub _set_section_defaults ( $sections ) {
          my $v = $section->{$_};
          if ( defined $v and $v =~ /$is_digit/ ) {
             $v ||= "0 but true";
-            my $end  = ( $v >= 0 ) ? "pos" : "neg";   # Set negative or
-            my $name = "_${_}_$end";                  # postive form.
+            my $end  = ( $v >= 0 ) ? "pos" : "neg";    # Set negative or
+            my $name = "_${_}_$end";                   # postive form.
             $section->{$name} = $v;
          }
       }
@@ -641,6 +615,8 @@ sub _get_heads_regex ( $num ) {
 
 Lower level find command.
 
+TODO: Need to clean this up and possibly restructure.
+
 =cut
 
 sub _find ( $need, @groups ) {
@@ -650,108 +626,89 @@ sub _find ( $need, @groups ) {
       say "groups: ", dumper \@groups;
    }
 
-   my $tag         = $need->{tag};
-   my $text        = $need->{text};
-   my $keep        = $need->{keep};
-   my $nth         = $need->{nth};
    my $nth_p       = $need->{_nth_pos};         # Simplify code by already
    my $nth_n       = $need->{_nth_neg};         # knowing if neg or pos.
-   my $nth_group   = $need->{nth_group};
    my $nth_group_p = $need->{_nth_grou_pos};    # Set in _set_section_defaults.
    my $nth_group_n = $need->{_nth_grou_neg};
    my @found;
 
-   GROUP:
+ GROUP:
    for my $group ( @groups ) {
-      my @tries = ( $group );
-      my $prev  = $group->{prev} // [];
-      $prev = [@$prev];    # shallow copy
+      my @tries = ( $group );                  # Assume single group to process.
+      my @prev  = @{ $group->{prev} // [] };
       my $locked_prev = 0;
-      my @q;
+      my @found_in_group;
       if ( $DEBUG_FIND ) {
-         say "\nprev: ", dumper $prev;
+         say "\nprev: ", dumper \@prev;
          say "group:  ", dumper $group;
       }
 
-      while ( my $try = shift @tries ) {
-         $DEBUG_FIND
-           and say "\nTrying: try=", dumper $try;
+    TRY:
+      while ( my $try = shift @tries ) {   # Can add to this queue if a sub tag.
+         say "\nTrying: try=", dumper $try if $DEBUG_FIND;
 
-         my $_tag      = $try->{tag};
-         my ( $_text ) = $try->{text}->@*;
-         my $_sub      = $try->{sub};
-         my $_keep     = $try->{keep};
+         my ( $try_text ) = $try->{text}->@*;   # TODO: why only the first text?
 
-         if ( defined $_keep ) {
-            $DEBUG_FIND
-              and say "ENFORCING: keep";
+         if ( defined $try->{keep} ) {          # TODO; Why empty block?
+            say "ENFORCING: keep" if $DEBUG_FIND;
          }
-         elsif ($_tag =~ /$tag/
-            and $_text =~ /$text/ )
+         elsif ($try->{tag} =~ /$need->{tag}/
+            and $try_text =~ /$need->{text}/ )
          {
-            $DEBUG_FIND
-              and say "Found:  tag=$_tag, text=$_text";
-            push @q,
-              {
-               %$try,
-               prev => $prev,
-               keep => $keep,
-              };
+            say "Found:  tag=$try->{tag}, text=$try_text" if $DEBUG_FIND;
+            push @found_in_group, {
+               %$try,                    # Copy current search options.
+               prev => \@prev,           # Need this for the inversion step.
+               keep => $need->{keep},    # Remember for later.
+            };
 
             # Specific match (positive)
-            if ( $nth_p and @q > $nth_p ) {
-               $DEBUG_FIND
-                 and say "ENFORCING: nth=$nth";
-               @found = $q[$nth_p];
+            if ( $nth_p and @found_in_group > $nth_p ) {
+               say "ENFORCING: nth=$nth_p" if $DEBUG_FIND;
+               @found = $found_in_group[$nth_p];    # Big match
                last GROUP;
             }
 
             # Specific group match (positive)
-            elsif ( $nth_group_p and @q > $nth_group_p ) {
-               $DEBUG_FIND
-                 and say "ENFORCING: nth_group=$nth_group";
-               @q = $q[$nth_group_p];
-               last;
+            elsif ( $nth_group_p and @found_in_group > $nth_group_p ) {
+               say "ENFORCING: nth_group=$nth_group_p" if $DEBUG_FIND;
+               @found_in_group = $found_in_group[$nth_group_p];    # Submatch
+               last TRY;
             }
          }
 
-         if ( $_sub and not @q ) {
-            $DEBUG_FIND
-              and say "Got sub and nothing yet in queue";
-            unshift @tries, @$_sub;
-            if ( $_keep and not $locked_prev++ ) {
-               unshift @$prev,
+         if ( $try->{sub} and not @found_in_group ) {
+            say "Got sub and nothing yet in queue" if $DEBUG_FIND;
+            unshift @tries, $try->{sub}->@*;    # Process sub tags.
+            if ( $try->{keep} and not $locked_prev++ ) {
+               unshift @prev,
                  {
-                  tag  => $_tag,
-                  text => [$_text],
+                  tag  => $try->{tag},
+                  text => [$try_text],
                  };
-               $DEBUG_FIND
-                 and say "prev changed: ", dumper $prev;
+               say "prev changed: ", dumper \@prev if $DEBUG_FIND;
             }
-            $DEBUG_FIND
-              and say "locked_prev: $locked_prev";
+            say "locked_prev: $locked_prev" if $DEBUG_FIND;
          }
       }
 
       # Specific group match (negative)
-      if ( $nth_group_n and @q >= abs $nth_group_n ) {
-         $DEBUG_FIND
-           and say "ENFORCING: nth_group_n=$nth_group_n";
-         @q = $q[$nth_group_n];
+      if ( $nth_group_n and @found_in_group >= abs $nth_group_n ) {
+         say "ENFORCING: nth_group_n=$nth_group_n" if $DEBUG_FIND;
+         @found_in_group = $found_in_group[$nth_group_n];
       }
 
-      push @found, splice @q if @q;
+      push @found, splice @found_in_group if @found_in_group;
    }
 
    # Specific match (negative)
    if ( $nth_n and @found >= abs $nth_n ) {
-      $DEBUG_FIND
-        and say "ENFORCING: nth=$nth";
+      say "ENFORCING: nth=$nth_n" if $DEBUG_FIND;
       @found = $found[$nth_n];
    }
 
-   $DEBUG_FIND
-     and say "found: ", dumper \@found;
+   say "found: ", dumper \@found if $DEBUG_FIND;
+
    @found;
 }
 
@@ -1009,6 +966,14 @@ Tim Potapov, C<< <tim.potapov[AT]gmail.com> >>
 Please report any bugs or feature requests to L<https://github.com/poti1/pod-query/issues>.
 
 
+=head1 CAVEAT
+
+
+These options to _find() appear to only be currently working if set to o or -1:
+   nth
+   nth_group
+
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
